==> forecast-solar_4.2.0.orig.tar.gz: forecast_solar-4.2.0/tests/test_models.py <==
"""Test the models."""

from datetime import datetime

import pytest
from aresponses import ResponsesMockServer
from syrupy.assertion import SnapshotAssertion

from forecast_solar import AccountType, Estimate, ForecastSolar

from . import load_fixtures


@pytest.mark.freeze_time("2024-04-26T12:00:00+02:00")
async def test_estimated_forecast(
    aresponses: ResponsesMockServer,
    snapshot: SnapshotAssertion,
    forecast_client: ForecastSolar,
) -> None:
    """Test estimated forecast."""
    aresponses.add(
        "api.forecast.solar",
        "/estimate/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("forecast.json"),
        ),
    )
    forecast: Estimate = await forecast_client.estimate()
    assert forecast == snapshot
    assert forecast.timezone == "Europe/Amsterdam"
    assert forecast.account_type == AccountType.PUBLIC

    assert forecast.energy_production_today == 6660
    assert forecast.energy_production_tomorrow == 5338

    assert forecast.power_production_now == 773
    assert forecast.energy_production_today_remaining == 4144
    assert forecast.energy_current_hour == 821

    assert forecast.power_highest_peak_time_today == datetime.fromisoformat(
        "2024-04-26T11:00:00+02:00"
    )
    assert forecast.power_highest_peak_time_tomorrow == datetime.fromisoformat(
        "2024-04-27T12:00:00+02:00"
    )

    assert forecast.sum_energy_production(1) == 742
    assert forecast.sum_energy_production(6) == 3093
    assert forecast.sum_energy_production(12) == 3323
    assert forecast.sum_energy_production(24) == 5633


@pytest.mark.freeze_time("2024-04-27T07:00:00+02:00")
async def test_estimated_forecast_with_subscription(
    aresponses: ResponsesMockServer,
    snapshot: SnapshotAssertion,
    forecast_key_client: ForecastSolar,
) -> None:
    """Test estimated forecast."""
    aresponses.add(
        "api.forecast.solar",
        "/myapikey/estimate/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "60",
                "X-Ratelimit-Period": "3600",
            },
            text=load_fixtures("forecast_personal.json"),
        ),
    )
    forecast: Estimate = await forecast_key_client.estimate()
    assert forecast == snapshot
    assert forecast.timezone == "Europe/Amsterdam"
    assert forecast.account_type == AccountType.PERSONAL

    assert forecast.energy_production_today == 5788
    assert forecast.energy_production_tomorrow == 7507

    assert forecast.power_production_now == 92
    assert forecast.energy_production_today_remaining == 5783
    assert forecast.energy_current_hour == 96

    assert forecast.power_highest_peak_time_today == datetime.fromisoformat(
        "2024-04-27T13:30:00+02:00"
    )
    assert forecast.power_highest_peak_time_tomorrow == datetime.fromisoformat(
        "2024-04-28T14:30:00+02:00"
    )

    assert forecast.sum_energy_production(1) == 216
    assert forecast.sum_energy_production(6) == 2802
    assert forecast.sum_energy_production(12) == 5582
    assert forecast.sum_energy_production(24) == 5784


@pytest.mark.freeze_time("2024-04-27T07:00:00+02:00")
async def test_estimated_forecast_with_subscription_and_actual_value(
    aresponses: ResponsesMockServer,
    snapshot: SnapshotAssertion,
    forecast_key_client: ForecastSolar,
) -> None:
    """Test estimated forecast."""
    aresponses.add(
        "api.forecast.solar",
        "/myapikey/estimate/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "60",
                "X-Ratelimit-Period": "3600",
            },
            text=load_fixtures("forecast_personal.json"),
        ),
    )
    forecast: Estimate = await forecast_key_client.estimate(actual=2.300)
    assert forecast == snapshot
    assert forecast.timezone == "Europe/Amsterdam"
    assert forecast.account_type == AccountType.PERSONAL

    assert forecast.energy_production_today == 5788
    assert forecast.energy_production_tomorrow == 7507

    assert forecast.sum_energy_production(1) == 216
    assert forecast.sum_energy_production(6) == 2802
    assert forecast.sum_energy_production(12) == 5582
    assert forecast.sum_energy_production(24) == 5784


async def test_api_key_validation(
    aresponses: ResponsesMockServer,
    forecast_key_client: ForecastSolar,
) -> None:
    """Test API key validation."""
    aresponses.add(
        "api.forecast.solar",
        "/myapikey/info",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("validate_key.json"),
        ),
    )
    assert await forecast_key_client.validate_api_key() is True


async def test_plane_validation(
    aresponses: ResponsesMockServer,
    forecast_client: ForecastSolar,
) -> None:
    """Test plane validation."""
    aresponses.add(
        "api.forecast.solar",
        "/check/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("validate_plane.json"),
        ),
    )
    assert await forecast_client.validate_plane() is True

==> forecast-solar_5.0.0.orig.tar.gz: forecast_solar-5.0.0/tests/test_models.py <==
"""Test the models."""

from datetime import datetime

import pytest
from aresponses import ResponsesMockServer
from syrupy.assertion import SnapshotAssertion

from forecast_solar import AccountType, Estimate, ForecastSolar, Plane

from . import load_fixtures


@pytest.mark.freeze_time("2024-04-26T12:00:00+02:00")
async def test_estimated_forecast(
    aresponses: ResponsesMockServer,
    snapshot: SnapshotAssertion,
    forecast_client: ForecastSolar,
) -> None:
    """Test estimated forecast."""
    aresponses.add(
        "api.forecast.solar",
        "/estimate/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("forecast.json"),
        ),
    )
    forecast: Estimate = await forecast_client.estimate()
    assert forecast == snapshot
    assert forecast.timezone == "Europe/Amsterdam"
    assert forecast.account_type == AccountType.PUBLIC

    assert forecast.energy_production_today == 6660
    assert forecast.energy_production_tomorrow == 5338

    assert forecast.power_production_now == 773
    assert forecast.energy_production_today_remaining == 4144
    assert forecast.energy_current_hour == 821

    assert forecast.power_highest_peak_time_today == datetime.fromisoformat(
        "2024-04-26T11:00:00+02:00"
    )
    assert forecast.power_highest_peak_time_tomorrow == datetime.fromisoformat(
        "2024-04-27T12:00:00+02:00"
    )

    assert forecast.sum_energy_production(1) == 742
    assert forecast.sum_energy_production(6) == 3093
    assert forecast.sum_energy_production(12) == 3323
    assert forecast.sum_energy_production(24) == 5633


@pytest.mark.freeze_time("2024-04-27T07:00:00+02:00")
async def test_estimated_forecast_with_subscription(
    aresponses: ResponsesMockServer,
    snapshot: SnapshotAssertion,
    forecast_key_client: ForecastSolar,
) -> None:
    """Test estimated forecast."""
    aresponses.add(
        "api.forecast.solar",
        "/myapikey/estimate/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "60",
                "X-Ratelimit-Period": "3600",
            },
            text=load_fixtures("forecast_personal.json"),
        ),
    )
    forecast: Estimate = await forecast_key_client.estimate()
    assert forecast == snapshot
    assert forecast.timezone == "Europe/Amsterdam"
    assert forecast.account_type == AccountType.PERSONAL

    assert forecast.energy_production_today == 5788
    assert forecast.energy_production_tomorrow == 7507

    assert forecast.power_production_now == 92
    assert forecast.energy_production_today_remaining == 5783
    assert forecast.energy_current_hour == 96

    assert forecast.power_highest_peak_time_today == datetime.fromisoformat(
        "2024-04-27T13:30:00+02:00"
    )
    assert forecast.power_highest_peak_time_tomorrow == datetime.fromisoformat(
        "2024-04-28T14:30:00+02:00"
    )

    assert forecast.sum_energy_production(1) == 216
    assert forecast.sum_energy_production(6) == 2802
    assert forecast.sum_energy_production(12) == 5582
    assert forecast.sum_energy_production(24) == 5784


@pytest.mark.freeze_time("2024-04-27T07:00:00+02:00")
async def test_estimated_forecast_with_subscription_and_actual_value(
    aresponses: ResponsesMockServer,
    snapshot: SnapshotAssertion,
    forecast_key_client: ForecastSolar,
) -> None:
    """Test estimated forecast."""
    aresponses.add(
        "api.forecast.solar",
        "/myapikey/estimate/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "60",
                "X-Ratelimit-Period": "3600",
            },
            text=load_fixtures("forecast_personal.json"),
        ),
    )
    forecast: Estimate = await forecast_key_client.estimate(actual=2.300)
    assert forecast == snapshot
    assert forecast.timezone == "Europe/Amsterdam"
    assert forecast.account_type == AccountType.PERSONAL

    assert forecast.energy_production_today == 5788
    assert forecast.energy_production_tomorrow == 7507

    assert forecast.sum_energy_production(1) == 216
    assert forecast.sum_energy_production(6) == 2802
    assert forecast.sum_energy_production(12) == 5582
    assert forecast.sum_energy_production(24) == 5784


async def test_api_key_validation(
    aresponses: ResponsesMockServer,
    forecast_key_client: ForecastSolar,
) -> None:
    """Test API key validation."""
    aresponses.add(
        "api.forecast.solar",
        "/myapikey/info",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("validate_key.json"),
        ),
    )
    assert await forecast_key_client.validate_api_key() is True


async def test_plane_validation(
    aresponses: ResponsesMockServer,
    forecast_client: ForecastSolar,
) -> None:
    """Test plane validation."""
    aresponses.add(
        "api.forecast.solar",
        "/check/52.16/4.47/20/10/2.16",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("validate_plane.json"),
        ),
    )
    assert await forecast_client.validate_plane() is True


@pytest.mark.freeze_time("2024-04-26T12:00:00+02:00")
async def test_estimated_forecast_multi_plane(
    aresponses: ResponsesMockServer,
    snapshot: SnapshotAssertion,
    forecast_multi_plane_client: ForecastSolar,
) -> None:
    """Test estimated forecast with multiple planes."""
    aresponses.add(
        "api.forecast.solar",
        "/myapikey/estimate/52.16/4.47/20/10/2.16/30/-90/1.5",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "60",
                "X-Ratelimit-Period": "3600",
            },
            text=load_fixtures("forecast_personal.json"),
        ),
    )
    forecast: Estimate = await forecast_multi_plane_client.estimate()
    assert forecast == snapshot
    assert forecast.timezone == "Europe/Amsterdam"
    assert forecast.account_type == AccountType.PERSONAL


async def test_multi_plane_validation(
    aresponses: ResponsesMockServer,
    forecast_multi_plane_client: ForecastSolar,
) -> None:
    """Test plane validation with multiple planes."""
    aresponses.add(
        "api.forecast.solar",
        "/check/52.16/4.47/20/10/2.16/30/-90/1.5",
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("validate_plane.json"),
        ),
    )
    assert await forecast_multi_plane_client.validate_plane() is True


async def test_planes_ignored_without_api_key(
    aresponses: ResponsesMockServer,
) -> None:
    """Test that planes are silently ignored when no API key is provided."""
    # When no API key is provided, planes should be ignored
    # and only the primary plane used
    aresponses.add(
        "api.forecast.solar",
        "/estimate/52.16/4.47/20/10/2.16",  # Only primary plane, no additional planes
        "GET",
        aresponses.Response(
            status=200,
            headers={
                "Content-Type": "application/json",
                "X-Ratelimit-Limit": "10",
                "X-Ratelimit-Period": "1",
            },
            text=load_fixtures("forecast.json"),
        ),
    )
    async with ForecastSolar(
        latitude=52.16,
        longitude=4.47,
        declination=20,
        azimuth=10,
        kwp=2.160,
        planes=[
            Plane(declination=30, azimuth=-90, kwp=1.5),
        ],
    ) as forecast:
        estimate = await forecast.estimate()
        assert estimate is not None
